export interface Post {
    /**
     * Post ID.
     * @readonly
     */
    _id?: string | null;
    /** Category ID the post is listed under. */
    categoryId?: string;
    /**
     * Post owner's member ID.
     * @readonly
     */
    ownerId?: string | null;
    /** Post title. */
    title?: string | null;
    /** The post content in plain text. */
    contentText?: string | null;
    /**
     * Total number of post comments.
     * @readonly
     */
    commentCount?: number | null;
    /**
     * Total number of post likes.
     * @readonly
     */
    likeCount?: number | null;
    /**
     * Total number of post views.
     * @readonly
     */
    viewCount?: number | null;
    /**
     * Date post was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date of latest activity on this post (e.g., date the latest comment was added to post).
     * @readonly
     */
    lastActivityDate?: Date | null;
    /**
     * Post URL.
     * @readonly
     */
    url?: string;
    /**
     * Post slug.
     * @readonly
     */
    slug?: string | null;
    /**
     * @internal
     * @internal
     * @readonly
     * @deprecated
     */
    bestAnswerCommentId?: string | null;
    /**
     * Images from post content.
     * @readonly
     */
    images?: string[];
    /**
     * Videos from post content.
     * @readonly
     */
    videos?: string[];
    /** Whether the post is pinned. Places the post at the top of the post list. */
    pinned?: boolean | null;
    /** Whether post is closed and commenting is disabled. */
    closed?: boolean | null;
    /** Date post was updated. */
    _updatedDate?: Date | null;
    /** Defines what interactions may be applied on the comment under the post, vote or like. */
    commentInteraction?: Interaction;
    /**
     * IDs of the marked comments for this post. Posts are marked by the forum admin or the post owner.
     * @readonly
     */
    markedComments?: string[];
    /**
     * Recent activity of post. For example, a comment added to a post.
     * @readonly
     */
    recentActivity?: RecentActivity;
    /**
     * List of reaction identities grouped by reaction code.
     * @readonly
     */
    reactionIdentities?: ReactionIdentity[];
}
export declare enum PostType {
    DISCUSSION = "DISCUSSION",
    QUESTION = "QUESTION"
}
export interface FocalPoint {
    /** X-coordinate of the focal point. */
    x?: number;
    /** Y-coordinate of the focal point. */
    y?: number;
    /** crop by height */
    height?: number | null;
    /** crop by width */
    width?: number | null;
}
export interface VideoResolution {
    /** Video URL. */
    url?: string;
    /** Video height. */
    height?: number;
    /** Video width. */
    width?: number;
    /** Video format for example, mp4, hls. */
    format?: string;
}
export declare enum Interaction {
    UNKNOWN = "UNKNOWN",
    REACTION = "REACTION",
    VOTE = "VOTE",
    NONE = "NONE"
}
export interface RecentActivity extends RecentActivityInitiatorOneOf {
    /** Site member ID. */
    memberId?: string;
    /** ID of recent activity entity. */
    entityId?: string;
    /** Type of entity. */
    type?: EntityType;
    /** Date activity was created. */
    activityDate?: string;
}
/** @oneof */
export interface RecentActivityInitiatorOneOf {
    /** Site member ID. */
    memberId?: string;
}
export declare enum EntityType {
    UNKNOWN = "UNKNOWN",
    COMMENT = "COMMENT",
    REPLY = "REPLY"
}
export interface ReactionCodeCount {
    /** Reaction code. */
    reactionCode?: string;
    /** Total number of reaction. */
    count?: number;
}
export interface ReactionIdentity {
    /** Reaction code. */
    reactionCode?: string;
    /**
     * Reacted identities.
     * @readonly
     */
    identities?: Identity[];
    /** Total number of reacted identities count. */
    count?: number;
}
export declare enum IdentityType {
    UNKNOWN = "UNKNOWN",
    VISITOR = "VISITOR",
    MEMBER = "MEMBER"
}
export interface Identity {
    /** Identity id. */
    identityId?: string;
    /** Reacted identity type. */
    identityType?: IdentityType;
}
export interface Moved {
    /** Old category ID. */
    oldCategoryId?: string;
    /** New current category ID. */
    currentCategoryId?: string;
    /** ID of the moved post. */
    postId?: string;
}
export interface Liked {
    /** ID of the liked post. */
    postId?: string;
}
export interface Unliked {
    /** ID of the unliked post. */
    postId?: string;
}
export interface Pinned {
    /** ID of the pinned post. */
    postId?: string;
}
export interface Unpinned {
    /** ID of the unpinned post. */
    postId?: string;
}
export interface Closed {
    /** ID of the closed post. */
    postId?: string;
}
export interface Opened {
    /** ID of the opened post. */
    postId?: string;
}
export interface Reported {
    /** Type of report. */
    reportType?: ReportType;
    /** ID of the reported post. */
    postId?: string;
}
export declare enum ReportType {
    OFFENSIVE_CONTENT = "OFFENSIVE_CONTENT",
    OFFENSIVE_MEDIA = "OFFENSIVE_MEDIA",
    SPAM = "SPAM"
}
export interface Reacted {
    postId?: string;
    reactionCode?: string;
}
export interface Unreacted {
    postId?: string;
    reactionCode?: string;
}
export interface PostRequest {
    /** Post ID. */
    postId: string;
    /** Array of extra post fields to be added in the response. */
    extraFields?: Field[];
}
export declare enum PostFieldField {
    UNKNOWN = "UNKNOWN",
    /** Includes Post content as a stringified DraftJS document (internal only). */
    CONTENT = "CONTENT",
    /** Includes images from Post content (internal only). */
    IMAGES = "IMAGES",
    /** Includes videos from Post content (internal only). */
    VIDEOS = "VIDEOS",
    /** Includes Post URL. */
    URL = "URL",
    /** Includes Post content as a stringified Rich Content document (internal only). */
    RICH_CONTENT = "RICH_CONTENT"
}
export declare enum Field {
    /** Undefined field type. */
    UNKNOWN = "UNKNOWN",
    /** Include images from post content. */
    IMAGES = "IMAGES",
    /** Include videos from post content. */
    VIDEOS = "VIDEOS",
    /** Include post URL. */
    URL = "URL",
    /** Include reaction identities. */
    REACTION_IDENTITIES = "REACTION_IDENTITIES"
}
export interface PostResponse {
    /** Post for the provided post ID. */
    post?: Post;
}
export interface PostSlugRequest {
    /** URL slug. */
    slug: string;
    /** Array of extra post fields to be added in the response. */
    extraFields?: Field[];
}
export interface QueryPostsRequest {
    /** Paging object (e.g., { limit: 10, offset: 100 } ). */
    paging?: PostsPaging;
    /** Filter object (e.g., { $and: [{ ownerId: { eq: 'ownerId' } }, { likeCount: { $gt: 0 }] } ). */
    filter?: Record<string, any> | null;
    /** Array of sort objects (e.g.,  [{ fieldName: createdDate, order: Order.ASC }] ). */
    sort?: PostsSort[];
    /** Array of extra post fields to be added in the response. */
    extraFields?: Field[];
}
export interface PostsPaging {
    /** The number of items to load. */
    limit?: number;
    /** Number of items to skip in the current sort order. */
    offset?: number;
}
export interface PostsSort {
    /**
     * Records can be sorted by:
     * lastActivityDate
     * createdDate
     * commentCount
     * viewCount
     * likeCount
     * isPinned
     */
    fieldName?: string;
    /** Records can be sorted in ascending (default) or descending order. */
    order?: Order;
}
export declare enum Order {
    /** Sort by ascending order. */
    ASC = "ASC",
    /** Sort by descending order. */
    DESC = "DESC"
}
export interface QueryPostsResponse {
    /** List of posts. */
    posts?: Post[];
    /** Pagination. */
    metaData?: QueryPostsResponseMetaData;
}
export interface QueryPostsResponseMetaData {
    /** Total number of records returned. */
    count?: number;
    /** Offset of records. */
    offset?: number;
    /** Total number of records that match the filters. */
    total?: number;
}
export interface ViewPostRequest {
    /** ID of the read post. */
    postId?: string;
}
export interface ViewPostResponse {
}
export interface MarkPostReadRequest {
    /** ID of the read post. */
    postId?: string;
}
export interface MarkPostReadResponse {
}
export interface MarkPostsSeenRequest {
    /** IDs of the seen posts. */
    postsIds?: string[];
}
export interface MarkPostsSeenResponse {
}
export interface MarkPostUnreadRequest {
    /** ID of the unread post. */
    postId?: string;
}
export interface MarkPostUnreadResponse {
}
export interface CreatePostRequest {
    /** New post to create. */
    post?: Post;
}
export interface CreatePostResponse {
    /** Created post. */
    post?: Post;
}
export interface UpdatePostRequest {
    /** ID of the post to update. */
    postId?: string;
    /** Field mask of fields to update. */
    fieldMask?: string[];
    /** Post data with partial data to update. */
    post?: Post;
}
export interface UpdatePostResponse {
    /** Updated post. */
    post?: Post;
}
export interface DeletePostRequest {
    /** ID of the post to delete. */
    postId?: string;
}
export interface DeletePostResponse {
    /** Deleted post. */
    post?: Post;
}
export interface SetBestAnswerRequest {
    /** Post ID. */
    postId?: string;
    /** ID of the "best answer" comment on the post. */
    commentId?: string;
}
export interface SetBestAnswerResponse {
}
export interface RemoveBestAnswerRequest {
    /** Post ID */
    postId?: string;
}
export interface RemoveBestAnswerResponse {
}
export interface PinPostRequest {
    /** Post ID */
    postId?: string;
    /** The amount of minutes after which the pin will be removed (unpinned) */
    expiresInMinutes?: number | null;
}
export interface PinPostResponse {
}
export interface UnpinPostRequest {
    /** Post ID */
    postId?: string;
}
export interface UnpinPostResponse {
}
export interface AddReactionRequest {
    /** Post ID */
    postId?: string;
    /** Code of reaction to add. */
    reactionCode?: string;
}
export interface AddReactionResponse {
    /**
     * Total number of comment reactions.
     * @readonly
     */
    reactionCount?: number;
    /**
     * List of reacted identities grouped by reaction code.
     * @readonly
     */
    reactionIdentities?: ReactionIdentity[];
}
export interface RemoveReactionRequest {
    /** Post ID */
    postId?: string;
    /** Code of reaction to remove. */
    reactionCode?: string;
}
export interface RemoveReactionResponse {
    /**
     * Total number of comment reactions.
     * @readonly
     */
    reactionCount?: number;
    /**
     * List of reacted identities grouped by reaction code.
     * @readonly
     */
    reactionIdentities?: ReactionIdentity[];
}
export interface ReportPostRequest {
    /** Post ID */
    postId?: string;
    /** Type of report. */
    reportType?: ReportType;
}
export interface ReportPostResponse {
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    _id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entity?: string;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted */
    deletedEntity?: string | null;
}
export interface ActionEvent {
    body?: string;
}
export interface MessageEnvelope {
    /** App instance ID. */
    instanceId?: string | null;
    /** Event type. */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityType;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
interface RecentActivityNonNullableFields {
    memberId: string;
    entityId: string;
    type: EntityType;
    activityDate: string;
}
interface ReactionCodeCountNonNullableFields {
    reactionCode: string;
    count: number;
}
interface IdentityNonNullableFields {
    identityId: string;
    identityType: IdentityType;
}
interface ReactionIdentityNonNullableFields {
    reactionCode: string;
    identities: IdentityNonNullableFields[];
    count: number;
}
export interface PostNonNullableFields {
    categoryId: string;
    url: string;
    postType: PostType;
    images: string[];
    videos: string[];
    commentInteraction: Interaction;
    markedComments: string[];
    recentActivity?: RecentActivityNonNullableFields;
    reactionCount: number;
    reactionCodeCounts: ReactionCodeCountNonNullableFields[];
    reactionIdentities: ReactionIdentityNonNullableFields[];
}
export interface PostResponseNonNullableFields {
    post?: PostNonNullableFields;
}
interface QueryPostsResponseMetaDataNonNullableFields {
    count: number;
    offset: number;
    total: number;
}
export interface QueryPostsResponseNonNullableFields {
    posts: PostNonNullableFields[];
    metaData?: QueryPostsResponseMetaDataNonNullableFields;
}
export interface BaseEventMetadata {
    /** App instance ID. */
    instanceId?: string | null;
    /** Event type. */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
export interface EventMetadata extends BaseEventMetadata {
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    _id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
export interface PostClosedEnvelope {
    data: Closed;
    metadata: EventMetadata;
}
/**
 * An existing post was closed for further comments.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_closed
 * @documentationMaturity preview
 */
export declare function onPostClosed(handler: (event: PostClosedEnvelope) => void | Promise<void>): void;
export interface PostCreatedEnvelope {
    entity: Post;
    metadata: EventMetadata;
}
/**
 * A new post was created.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_created
 * @documentationMaturity preview
 */
export declare function onPostCreated(handler: (event: PostCreatedEnvelope) => void | Promise<void>): void;
export interface PostDeletedEnvelope {
    metadata: EventMetadata;
}
/**
 * An existing post was removed.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_deleted
 * @documentationMaturity preview
 */
export declare function onPostDeleted(handler: (event: PostDeletedEnvelope) => void | Promise<void>): void;
export interface PostLikedEnvelope {
    data: Liked;
    metadata: EventMetadata;
}
/**
 * An existing post was liked.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_liked
 * @documentationMaturity preview
 */
export declare function onPostLiked(handler: (event: PostLikedEnvelope) => void | Promise<void>): void;
export interface PostMovedEnvelope {
    data: Moved;
    metadata: EventMetadata;
}
/**
 * An existing post was moved to a different category.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_moved
 * @documentationMaturity preview
 */
export declare function onPostMoved(handler: (event: PostMovedEnvelope) => void | Promise<void>): void;
export interface PostOpenedEnvelope {
    data: Opened;
    metadata: EventMetadata;
}
/**
 * An existing post was opened for further comments.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_opened
 * @documentationMaturity preview
 */
export declare function onPostOpened(handler: (event: PostOpenedEnvelope) => void | Promise<void>): void;
export interface PostPinnedEnvelope {
    data: Pinned;
    metadata: EventMetadata;
}
/**
 * An existing post was pinned to the top of the post list.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_pinned
 * @documentationMaturity preview
 */
export declare function onPostPinned(handler: (event: PostPinnedEnvelope) => void | Promise<void>): void;
export interface PostReactedEnvelope {
    data: Reacted;
    metadata: EventMetadata;
}
/**
 * An existing post was reacted.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_reacted
 * @documentationMaturity preview
 */
export declare function onPostReacted(handler: (event: PostReactedEnvelope) => void | Promise<void>): void;
export interface PostReportedEnvelope {
    data: Reported;
    metadata: EventMetadata;
}
/**
 * An existing post was reported as inappropriate.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_reported
 * @documentationMaturity preview
 */
export declare function onPostReported(handler: (event: PostReportedEnvelope) => void | Promise<void>): void;
export interface PostUnlikedEnvelope {
    data: Unliked;
    metadata: EventMetadata;
}
/**
 * An existing post was unliked.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_unliked
 * @documentationMaturity preview
 */
export declare function onPostUnliked(handler: (event: PostUnlikedEnvelope) => void | Promise<void>): void;
export interface PostUnpinnedEnvelope {
    data: Unpinned;
    metadata: EventMetadata;
}
/**
 * An existing post was unpinned from the top of the post list.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_unpinned
 * @documentationMaturity preview
 */
export declare function onPostUnpinned(handler: (event: PostUnpinnedEnvelope) => void | Promise<void>): void;
export interface PostUnreactedEnvelope {
    data: Unreacted;
    metadata: EventMetadata;
}
/**
 * An existing post was unreacted.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_unreacted
 * @documentationMaturity preview
 */
export declare function onPostUnreacted(handler: (event: PostUnreactedEnvelope) => void | Promise<void>): void;
export interface PostUpdatedEnvelope {
    entity: Post;
    metadata: EventMetadata;
}
/**
 * An existing post was updated.
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @permissionId WIX_FORUM.CATEGORY_READ_ALL
 * @webhook
 * @eventType wix.forum.post_updated
 * @documentationMaturity preview
 */
export declare function onPostUpdated(handler: (event: PostUpdatedEnvelope) => void | Promise<void>): void;
/**
 * Retrieves a single post by ID.
 * @param postId - Post ID.
 * @public
 * @documentationMaturity preview
 * @requiredField postId
 * @param options - Options specifying which additional fields to return.
 * @permissionId WIX_FORUM.POST_READ
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @applicableIdentity APP
 * @returns Post for the provided post ID.
 * @fqn com.wixpress.npm.communities.forum.api.PostManagementService.GetPost
 */
export declare function getPost(postId: string, options?: GetPostOptions): Promise<Post & PostNonNullableFields>;
export interface GetPostOptions {
    /** Array of extra post fields to be added in the response. */
    extraFields?: Field[];
}
/**
 * Retrieves a single post by URL slug.
 * @param slug - URL slug.
 * @public
 * @documentationMaturity preview
 * @requiredField slug
 * @param options - Options specifying which additional fields to return.
 * @permissionId WIX_FORUM.POST_READ
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @applicableIdentity APP
 * @fqn com.wixpress.npm.communities.forum.api.PostManagementService.GetPostBySlug
 */
export declare function getPostBySlug(slug: string, options?: GetPostBySlugOptions): Promise<PostResponse & PostResponseNonNullableFields>;
export interface GetPostBySlugOptions {
    /** Array of extra post fields to be added in the response. */
    extraFields?: Field[];
}
/**
 * Returns a list of posts by query.
 *
 * Paging
 * - limit: default - 10, min - 0, max - 100
 * - offset: default - 0, min - 0
 *
 * Filterable fields:
 * - id
 * - categoryId
 * - ownerId
 * - title
 * - contentText
 * - bestAnswerCommentId
 * - pinned
 * - commentingEnabled
 * - commentCount
 * - likeCount
 * - viewCount
 * - createdDate
 * - editedDate
 * - lastActivityDate
 * - slug
 *
 * Sortable fields:
 * - lastActivityDate
 * - createdDate
 * - commentCount
 * - viewCount
 * - likeCount
 * - pinned
 * @public
 * @documentationMaturity preview
 * @param options - Options for sorting, filtering, paging, and specifying return fields.
 * @permissionId WIX_FORUM.POST_READ
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @applicableIdentity APP
 * @fqn com.wixpress.npm.communities.forum.api.PostManagementService.QueryPosts
 */
export declare function queryPosts(options?: QueryPostsOptions): Promise<QueryPostsResponse & QueryPostsResponseNonNullableFields>;
export interface QueryPostsOptions {
    /** Paging object (e.g., { limit: 10, offset: 100 } ). */
    paging?: PostsPaging;
    /** Filter object (e.g., { $and: [{ ownerId: { eq: 'ownerId' } }, { likeCount: { $gt: 0 }] } ). */
    filter?: Record<string, any> | null;
    /** Array of sort objects (e.g.,  [{ fieldName: createdDate, order: Order.ASC }] ). */
    sort?: PostsSort[];
    /** Array of extra post fields to be included in the response. */
    extraFields?: Field[];
}
export {};
