export interface Post {
    /**
     * Post ID.
     * @readonly
     */
    id?: string | null;
    /** Category ID the post is listed under. */
    categoryId?: string;
    /**
     * Post owner's member ID.
     * @readonly
     */
    ownerId?: string | null;
    /** Post title. */
    title?: string | null;
    /** The post content in plain text. */
    contentText?: string | null;
    /**
     * Total number of post comments.
     * @readonly
     */
    commentCount?: number | null;
    /**
     * Total number of post likes.
     * @readonly
     */
    likeCount?: number | null;
    /**
     * Total number of post views.
     * @readonly
     */
    viewCount?: number | null;
    /**
     * Date post was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date of latest activity on this post (e.g., date the latest comment was added to post).
     * @readonly
     */
    lastActivityDate?: Date | null;
    /**
     * Post URL.
     * @readonly
     */
    url?: PageUrl;
    /**
     * Post slug.
     * @readonly
     */
    slug?: string | null;
    /**
     * ID of the best answer comment for this post (selected by forum admin or post owner).
     * Deprecated on '2022-08-24' use markedComments instead.
     * @readonly
     * @deprecated
     */
    bestAnswerCommentId?: string | null;
    /**
     * Images from post content.
     * @readonly
     */
    images?: Image[];
    /**
     * Videos from post content.
     * @readonly
     */
    videos?: VideoV2[];
    /** Whether the post is pinned. Places the post at the top of the post list. */
    pinned?: boolean | null;
    /** Whether post is closed and commenting is disabled. */
    closed?: boolean | null;
    /** Date post was updated. */
    updatedDate?: Date | null;
    /** Defines what interactions may be applied on the comment under the post, vote or like. */
    commentInteraction?: Interaction;
    /**
     * IDs of the marked comments for this post. Posts are marked by the forum admin or the post owner.
     * @readonly
     */
    markedComments?: string[];
    /**
     * Recent activity of post. For example, a comment added to a post.
     * @readonly
     */
    recentActivity?: RecentActivity;
    /**
     * List of reaction identities grouped by reaction code.
     * @readonly
     */
    reactionIdentities?: ReactionIdentity[];
}
export interface PageUrl {
    /** The base URL. For premium sites, this is the domain. For free sites, this is the site URL. For example, `mysite.wixsite.com/mysite`. */
    base?: string;
    /** The relative path for the page within the site. For example, `/product-page/a-product`. */
    path?: string;
}
export declare enum PostType {
    DISCUSSION = "DISCUSSION",
    QUESTION = "QUESTION"
}
export interface Image {
    /** WixMedia image ID. */
    id?: string;
    /** Image URL. */
    url?: string;
    /**
     * Original image height.
     * @readonly
     */
    height?: number;
    /**
     * Original image width.
     * @readonly
     */
    width?: number;
    /** Image alt text. */
    altText?: string | null;
    /**
     * Image filename.
     * @readonly
     */
    filename?: string | null;
}
export interface FocalPoint {
    /** X-coordinate of the focal point. */
    x?: number;
    /** Y-coordinate of the focal point. */
    y?: number;
    /** crop by height */
    height?: number | null;
    /** crop by width */
    width?: number | null;
}
export interface VideoV2 {
    /** WixMedia ID. */
    id?: string;
    /**
     * Available resolutions for the video, starting with the optimal resolution.
     * @readonly
     */
    resolutions?: VideoResolution[];
    /**
     * Video filename.
     * @readonly
     */
    filename?: string | null;
}
export interface VideoResolution {
    /** Video URL. */
    url?: string;
    /** Video height. */
    height?: number;
    /** Video width. */
    width?: number;
    /** Video format for example, mp4, hls. */
    format?: string;
}
export declare enum Interaction {
    UNKNOWN = "UNKNOWN",
    REACTION = "REACTION",
    VOTE = "VOTE",
    NONE = "NONE"
}
export interface RecentActivity extends RecentActivityInitiatorOneOf {
    /** Site member ID. */
    memberId?: string;
    /** ID of recent activity entity. */
    entityId?: string;
    /** Type of entity. */
    type?: EntityType;
    /** Date activity was created. */
    activityDate?: string;
}
/** @oneof */
export interface RecentActivityInitiatorOneOf {
    /** Site member ID. */
    memberId?: string;
}
export declare enum EntityType {
    UNKNOWN = "UNKNOWN",
    COMMENT = "COMMENT",
    REPLY = "REPLY"
}
export interface ReactionCodeCount {
    /** Reaction code. */
    reactionCode?: string;
    /** Total number of reaction. */
    count?: number;
}
export interface ReactionIdentity {
    /** Reaction code. */
    reactionCode?: string;
    /**
     * Reacted identities.
     * @readonly
     */
    identities?: Identity[];
    /** Total number of reacted identities count. */
    count?: number;
}
export declare enum IdentityType {
    UNKNOWN = "UNKNOWN",
    VISITOR = "VISITOR",
    MEMBER = "MEMBER"
}
export interface Identity {
    /** Identity id. */
    identityId?: string;
    /** Reacted identity type. */
    identityType?: IdentityType;
}
export interface Moved {
    /** Old category ID. */
    oldCategoryId?: string;
    /** New current category ID. */
    currentCategoryId?: string;
    /** ID of the moved post. */
    postId?: string;
}
export interface Liked {
    /** ID of the liked post. */
    postId?: string;
}
export interface Unliked {
    /** ID of the unliked post. */
    postId?: string;
}
export interface Pinned {
    /** ID of the pinned post. */
    postId?: string;
}
export interface Unpinned {
    /** ID of the unpinned post. */
    postId?: string;
}
export interface Closed {
    /** ID of the closed post. */
    postId?: string;
}
export interface Opened {
    /** ID of the opened post. */
    postId?: string;
}
export interface Reported {
    /** Type of report. */
    reportType?: ReportType;
    /** ID of the reported post. */
    postId?: string;
}
export declare enum ReportType {
    OFFENSIVE_CONTENT = "OFFENSIVE_CONTENT",
    OFFENSIVE_MEDIA = "OFFENSIVE_MEDIA",
    SPAM = "SPAM"
}
export interface Reacted {
    postId?: string;
    reactionCode?: string;
}
export interface Unreacted {
    postId?: string;
    reactionCode?: string;
}
export interface PostRequest {
    /** Post ID. */
    postId: string;
    /** Array of extra post fields to be added in the response. */
    extraFields?: Field[];
}
export declare enum PostFieldField {
    UNKNOWN = "UNKNOWN",
    /** Includes Post content as a stringified DraftJS document (internal only). */
    CONTENT = "CONTENT",
    /** Includes images from Post content (internal only). */
    IMAGES = "IMAGES",
    /** Includes videos from Post content (internal only). */
    VIDEOS = "VIDEOS",
    /** Includes Post URL. */
    URL = "URL",
    /** Includes Post content as a stringified Rich Content document (internal only). */
    RICH_CONTENT = "RICH_CONTENT"
}
export declare enum Field {
    /** Undefined field type. */
    UNKNOWN = "UNKNOWN",
    /** Include images from post content. */
    IMAGES = "IMAGES",
    /** Include videos from post content. */
    VIDEOS = "VIDEOS",
    /** Include post URL. */
    URL = "URL",
    /** Include reaction identities. */
    REACTION_IDENTITIES = "REACTION_IDENTITIES"
}
export interface PostResponse {
    /** Post for the provided post ID. */
    post?: Post;
}
export interface PostSlugRequest {
    /** URL slug. */
    slug: string;
    /** Array of extra post fields to be added in the response. */
    extraFields?: Field[];
}
export interface QueryPostsRequest {
    /** Paging object (e.g., { limit: 10, offset: 100 } ). */
    paging?: PostsPaging;
    /** Filter object (e.g., { $and: [{ ownerId: { eq: 'ownerId' } }, { likeCount: { $gt: 0 }] } ). */
    filter?: Record<string, any> | null;
    /** Array of sort objects (e.g.,  [{ fieldName: createdDate, order: Order.ASC }] ). */
    sort?: PostsSort[];
    /** Array of extra post fields to be added in the response. */
    extraFields?: Field[];
}
export interface PostsPaging {
    /** The number of items to load. */
    limit?: number;
    /** Number of items to skip in the current sort order. */
    offset?: number;
}
export interface PostsSort {
    /**
     * Records can be sorted by:
     * lastActivityDate
     * createdDate
     * commentCount
     * viewCount
     * likeCount
     * isPinned
     */
    fieldName?: string;
    /** Records can be sorted in ascending (default) or descending order. */
    order?: Order;
}
export declare enum Order {
    /** Sort by ascending order. */
    ASC = "ASC",
    /** Sort by descending order. */
    DESC = "DESC"
}
export interface QueryPostsResponse {
    /** List of posts. */
    posts?: Post[];
    /** Pagination. */
    metaData?: QueryPostsResponseMetaData;
}
export interface QueryPostsResponseMetaData {
    /** Total number of records returned. */
    count?: number;
    /** Offset of records. */
    offset?: number;
    /** Total number of records that match the filters. */
    total?: number;
}
export interface ViewPostRequest {
    /** ID of the read post. */
    postId?: string;
}
export interface ViewPostResponse {
}
export interface MarkPostReadRequest {
    /** ID of the read post. */
    postId?: string;
}
export interface MarkPostReadResponse {
}
export interface MarkPostsSeenRequest {
    /** IDs of the seen posts. */
    postsIds?: string[];
}
export interface MarkPostsSeenResponse {
}
export interface MarkPostUnreadRequest {
    /** ID of the unread post. */
    postId?: string;
}
export interface MarkPostUnreadResponse {
}
export interface CreatePostRequest {
    /** New post to create. */
    post?: Post;
}
export interface CreatePostResponse {
    /** Created post. */
    post?: Post;
}
export interface UpdatePostRequest {
    /** ID of the post to update. */
    postId?: string;
    /** Field mask of fields to update. */
    fieldMask?: string[];
    /** Post data with partial data to update. */
    post?: Post;
}
export interface UpdatePostResponse {
    /** Updated post. */
    post?: Post;
}
export interface DeletePostRequest {
    /** ID of the post to delete. */
    postId?: string;
}
export interface DeletePostResponse {
    /** Deleted post. */
    post?: Post;
}
export interface SetBestAnswerRequest {
    /** Post ID. */
    postId?: string;
    /** ID of the "best answer" comment on the post. */
    commentId?: string;
}
export interface SetBestAnswerResponse {
}
export interface RemoveBestAnswerRequest {
    /** Post ID */
    postId?: string;
}
export interface RemoveBestAnswerResponse {
}
export interface PinPostRequest {
    /** Post ID */
    postId?: string;
    /** The amount of minutes after which the pin will be removed (unpinned) */
    expiresInMinutes?: number | null;
}
export interface PinPostResponse {
}
export interface UnpinPostRequest {
    /** Post ID */
    postId?: string;
}
export interface UnpinPostResponse {
}
export interface AddReactionRequest {
    /** Post ID */
    postId?: string;
    /** Code of reaction to add. */
    reactionCode?: string;
}
export interface AddReactionResponse {
    /**
     * Total number of comment reactions.
     * @readonly
     */
    reactionCount?: number;
    /**
     * List of reacted identities grouped by reaction code.
     * @readonly
     */
    reactionIdentities?: ReactionIdentity[];
}
export interface RemoveReactionRequest {
    /** Post ID */
    postId?: string;
    /** Code of reaction to remove. */
    reactionCode?: string;
}
export interface RemoveReactionResponse {
    /**
     * Total number of comment reactions.
     * @readonly
     */
    reactionCount?: number;
    /**
     * List of reacted identities grouped by reaction code.
     * @readonly
     */
    reactionIdentities?: ReactionIdentity[];
}
export interface ReportPostRequest {
    /** Post ID */
    postId?: string;
    /** Type of report. */
    reportType?: ReportType;
}
export interface ReportPostResponse {
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entityAsJson?: string;
    /** Indicates the event was triggered by a restore-from-trashbin operation for a previously deleted entity */
    restoreInfo?: RestoreInfo;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntityAsJson?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted */
    deletedEntityAsJson?: string | null;
}
export interface ActionEvent {
    bodyAsJson?: string;
}
export interface MessageEnvelope {
    /** App instance ID. */
    instanceId?: string | null;
    /** Event type. */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityType;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
interface PageUrlNonNullableFields {
    base: string;
    path: string;
}
interface FocalPointNonNullableFields {
    x: number;
    y: number;
}
interface ImageNonNullableFields {
    id: string;
    url: string;
    height: number;
    width: number;
    focalPoint?: FocalPointNonNullableFields;
}
interface VideoResolutionNonNullableFields {
    url: string;
    height: number;
    width: number;
    poster?: ImageNonNullableFields;
    format: string;
}
interface VideoV2NonNullableFields {
    id: string;
    url: string;
    resolutions: VideoResolutionNonNullableFields[];
    posters: ImageNonNullableFields[];
}
interface RecentActivityNonNullableFields {
    memberId: string;
    entityId: string;
    type: EntityType;
    activityDate: string;
}
interface ReactionCodeCountNonNullableFields {
    reactionCode: string;
    count: number;
}
interface IdentityNonNullableFields {
    identityId: string;
    identityType: IdentityType;
}
interface ReactionIdentityNonNullableFields {
    reactionCode: string;
    identities: IdentityNonNullableFields[];
    count: number;
}
interface PostNonNullableFields {
    categoryId: string;
    url?: PageUrlNonNullableFields;
    postType: PostType;
    images: ImageNonNullableFields[];
    videos: VideoV2NonNullableFields[];
    commentInteraction: Interaction;
    markedComments: string[];
    recentActivity?: RecentActivityNonNullableFields;
    reactionCount: number;
    reactionCodeCounts: ReactionCodeCountNonNullableFields[];
    reactionIdentities: ReactionIdentityNonNullableFields[];
}
export interface PostResponseNonNullableFields {
    post?: PostNonNullableFields;
}
interface QueryPostsResponseMetaDataNonNullableFields {
    count: number;
    offset: number;
    total: number;
}
export interface QueryPostsResponseNonNullableFields {
    posts: PostNonNullableFields[];
    metaData?: QueryPostsResponseMetaDataNonNullableFields;
}
export {};
